#!/usr/bin/env node

const mongodb = require("mongodb");
const exec = require("child_process").exec;

const MongoClient = mongodb.MongoClient;

async function migrate(
  source_url,
  target_url,
  src_db,
  target_db,
  target_username,
  target_password,
  collections,
  q
) {
  if (!target_db) {
    target_db = src_db;
  }
  var src_client = await new MongoClient(source_url, {
    useNewUrlParser: true,
  }).connect();

  var dst_client = new MongoClient(target_url).connect();
  exec(
    // `mongodump --uri=${source_url} --db=${src_db} ${source_username?'-u='+source_username:''} ${source_password?'-p='+source_password:''} --out=./dump ${ collections ? `--collection=${collections}` : "" } ${ q ? `--query=${q}` : "" }`,
    `mongodump --uri=${source_url} --db=${src_db}  --out=./dump ${
      collections ? `--collection=${collections}` : ""
    } ${q ? `--query=${q}` : ""}`,

    async (error, stdout, stderr) => {
      if (error) {
        console.log(`error: ${error.message}`);
        return;
      }
      if (stderr) {
        console.log(`stderr: ${stderr}`);
        console.log(
          `mongorestore  --uri=${target_url} --db=${target_db}  ${
            collections ? "--collection=" + collections : ""
          }  --authenticationDatabase=admin ./dump/${src_db}${
            collections ? "/" + collections : ""
          }`
        );
        exec(
          // `mongorestore  --uri=${target_url} --db=${target_db}  ${collections?"--collection="+collections:""} --username=${target_username} --password=${target_password} --authenticationDatabase=admin ./dump/${src_db}${collections?"/"+collections:""}`,
          `mongorestore  --uri=${target_url} --db=${target_db}  ${
            collections ? "--collection=" + collections : ""
          } --authenticationDatabase=admin ./dump/${src_db}${
            collections ? "/" + collections : ""
          }`,

          async (error, stdout, stderr) => {
            if (error) {
              console.log(`error: ${error.message}`);
              return;
            }
            if (stderr) {
              console.log(`stderr: ${stderr}`);
              return;
            }
            console.log(`stdout: ${stdout}`);

            console.log("Completed !");
            console.log("Closing connections ...");
            await src_client.close();
            await dst_client.close();

            //   delete the dump folder
            console.log("Deleting dump folder ...");
            exec("rm -rf ./dump", (error, stdout, stderr) => {
              if (error) {
                console.log(`error: ${error.message}`);
                return;
              }
              if (stderr) {
                console.log(`stderr: ${stderr}`);
                return;
              }
              console.log(`stdout: ${stdout}`);
            });
            console.log("Done !");
          }
        );
        return;
      }
      console.log(`stdout: ${stdout}`);
    }
  );
}

// migrate("mongodb://localhost:27017", "mongodb://195.176.181.158:27017/", "OAS-SE",undefined,"admin","oas2tree");

exports.migrate = migrate;
